@@ -1,6 +1,6 @@
 package IRC::Toolkit::Case;
-$IRC::Toolkit::Case::VERSION = '0.090001';
-use strictures 1;
+$IRC::Toolkit::Case::VERSION = '0.090002';
+use strictures 2;
 no warnings 'once';
 use Carp 'carp';
 
@@ -81,8 +81,7 @@ sub uc_irc ($;$) {
 
 sub eq_irc ($$;$) {
   my ($first, $second, $casemap) = @_;
-  return unless uc_irc($first, $casemap) eq uc_irc($second, $casemap);
-  1
+  uc_irc($first, $casemap) eq uc_irc($second, $casemap);
 }
 
 sub irc_str {
